==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/NextQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextQuarterExpressionDescription } from "./NextQuarterExpressionDescription";
/**
 * @hidden
 */
var NextQuarterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NextQuarterExpressionDescriptionMetadata, _super);
    function NextQuarterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NextQuarterExpressionDescriptionMetadata.b = function (a) {
        if (NextQuarterExpressionDescriptionMetadata.a == null) {
            NextQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NextQuarterExpressionDescriptionMetadata.c(NextQuarterExpressionDescriptionMetadata.a);
        }
        if (a.j(NextQuarterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(NextQuarterExpressionDescriptionMetadata.a);
    };
    NextQuarterExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    NextQuarterExpressionDescriptionMetadata.d = function (a) {
        NextQuarterExpressionDescriptionMetadata.b(a);
        a.aa("NextQuarterExpression", function () { return new NextQuarterExpressionDescription(); });
        a.z("NextQuarterExpression", NextQuarterExpressionDescriptionMetadata.a);
    };
    NextQuarterExpressionDescriptionMetadata.$t = markType(NextQuarterExpressionDescriptionMetadata, 'NextQuarterExpressionDescriptionMetadata');
    NextQuarterExpressionDescriptionMetadata.a = null;
    return NextQuarterExpressionDescriptionMetadata;
}(Base));
export { NextQuarterExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/NextQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextQuarterExpressionDescription } from "./NextQuarterExpressionDescription";
/**
 * @hidden
 */
var NextQuarterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NextQuarterExpressionDescriptionMetadata, _super);
    function NextQuarterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NextQuarterExpressionDescriptionMetadata.b = function (a) {
        if (NextQuarterExpressionDescriptionMetadata.a == null) {
            NextQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NextQuarterExpressionDescriptionMetadata.c(NextQuarterExpressionDescriptionMetadata.a);
        }
        if (a.k(NextQuarterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(NextQuarterExpressionDescriptionMetadata.a);
    };
    NextQuarterExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    NextQuarterExpressionDescriptionMetadata.d = function (a) {
        NextQuarterExpressionDescriptionMetadata.b(a);
        a.ac("NextQuarterExpression", function () { return new NextQuarterExpressionDescription(); });
        a.ab("NextQuarterExpression", NextQuarterExpressionDescriptionMetadata.a);
    };
    NextQuarterExpressionDescriptionMetadata.$t = markType(NextQuarterExpressionDescriptionMetadata, 'NextQuarterExpressionDescriptionMetadata');
    NextQuarterExpressionDescriptionMetadata.a = null;
    return NextQuarterExpressionDescriptionMetadata;
}(Base));
export { NextQuarterExpressionDescriptionMetadata };
